clc, clear
% initial
uavspan = 2.795; 
uavchord = 0.351;

% Used for basic experiments
% uavS = 0.982;
% uavmass = 8.165;

% used to design experiments and to modify the capacity of the battery
uavmass = 22.365 + 1.4;
b = 0.1239*sqrt(2.8217*uavmass*9.8);
c = 0.0156*sqrt(2.8217*uavmass*9.8);
uavS = b*c;

uavCD0 = 0.022;
uavApolar = 0.057;
% Environmental Parameters
envg = 9.81; 
envrho0 = 1.225;
% Propeller Parameters
Ct = 0.0984; % 
Cm = 0.0068; % 
Dp = 0.381; %cm
% Motor Parameters
Kv = 465; % 
Umax = 22.2; 
Kdecay = 12; 
Um0 = 10; 
Im0 = 2.4;
Rm = 0.016; 
% ESC Parameters
Ie = 80; 
Re =0.008; 
% Battery Parameters
Cb = 10000; 
Cmin = Cb * 0.15; 
Rb = 0.0084; 
Iother = 0.5; 
Ub= 22.2; 

% velocity
V = 22; 
%V = 14.6409;   
%V = 39.2865  
% V = 11.1247  
P_re = uavCD0 * 0.5 * envrho0 * uavS * V.^2 + uavApolar * ( uavmass * envg )^2 ./ (0.5 * envrho0 * uavS * V.^2 )

equation = @(x) x - Kdecay*V/sqrt(x) - P_re;
% fsolve
initialGuess = P_re;% initial guess
x_solution = fsolve(equation, initialGuess)


% Calculate the speed of the motor
N = 60 * sqrt(x_solution / (envrho0 * Dp^4 * Ct));
%N=7000;
% Calculate the torque of propeller
M = Cm * envrho0 * (N / 60)^2 * Dp^5;

% Calculate the equivalent current and voltage of the motor
Im = M * Kv * Um0 / 9.55 / (Um0 - Im0 * Rm) + Im0;
Um = Im * Rm + (Um0 - Im0 * Rm) * N / (Kv * Um0);

% Calculate the input throttle input current and input voltage of the electric modulation
sigma = (Um + Im * Re) / Ub;
Ie = Im * sigma;
Ib = Ie + Iother;
Ue = Ub - Ib * Rb;

% Calculate the battery discharge duration
Tb_s = (Cb - Cmin) / Ib;
Tb_mins = Tb_s * 60 /1000

% Calculating flight distance
L = V * Tb_mins*60